==> aws-cdk.aws-kinesisanalytics-flink-1.134.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_kinesisanalytics_flink_LogLevel(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_MetricsLevel(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_PropertyGroups(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_ApplicationCodeConfig(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_IApplication(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_Runtime(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_ApplicationCode(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_Application(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_ApplicationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_kinesisanalytics_flink_ApplicationCode(p.code);
    if (!visitedObjects.has(p.runtime))
        _aws_cdk_aws_kinesisanalytics_flink_Runtime(p.runtime);
    if (!visitedObjects.has(p.logLevel))
        _aws_cdk_aws_kinesisanalytics_flink_LogLevel(p.logLevel);
    if (!visitedObjects.has(p.metricsLevel))
        _aws_cdk_aws_kinesisanalytics_flink_MetricsLevel(p.metricsLevel);
    if (!visitedObjects.has(p.propertyGroups))
        _aws_cdk_aws_kinesisanalytics_flink_PropertyGroups(p.propertyGroups);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_kinesisanalytics_flink_LogLevel, _aws_cdk_aws_kinesisanalytics_flink_MetricsLevel, _aws_cdk_aws_kinesisanalytics_flink_PropertyGroups, _aws_cdk_aws_kinesisanalytics_flink_ApplicationCodeConfig, _aws_cdk_aws_kinesisanalytics_flink_IApplication, _aws_cdk_aws_kinesisanalytics_flink_Runtime, _aws_cdk_aws_kinesisanalytics_flink_ApplicationCode, _aws_cdk_aws_kinesisanalytics_flink_Application, _aws_cdk_aws_kinesisanalytics_flink_ApplicationProps };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-kinesisanalytics-flink-1.151.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_kinesisanalytics_flink_LogLevel(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_MetricsLevel(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_PropertyGroups(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_ApplicationCodeConfig(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_Runtime(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_ApplicationCode(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_ApplicationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_kinesisanalytics_flink_ApplicationCode(p.code);
    if (!visitedObjects.has(p.runtime))
        _aws_cdk_aws_kinesisanalytics_flink_Runtime(p.runtime);
    if (!visitedObjects.has(p.logLevel))
        _aws_cdk_aws_kinesisanalytics_flink_LogLevel(p.logLevel);
    if (!visitedObjects.has(p.metricsLevel))
        _aws_cdk_aws_kinesisanalytics_flink_MetricsLevel(p.metricsLevel);
    if (!visitedObjects.has(p.propertyGroups))
        _aws_cdk_aws_kinesisanalytics_flink_PropertyGroups(p.propertyGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisanalytics_flink_IApplication(p) {
}
function _aws_cdk_aws_kinesisanalytics_flink_Application(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_kinesisanalytics_flink_LogLevel, _aws_cdk_aws_kinesisanalytics_flink_MetricsLevel, _aws_cdk_aws_kinesisanalytics_flink_PropertyGroups, _aws_cdk_aws_kinesisanalytics_flink_ApplicationCodeConfig, _aws_cdk_aws_kinesisanalytics_flink_Runtime, _aws_cdk_aws_kinesisanalytics_flink_ApplicationCode, _aws_cdk_aws_kinesisanalytics_flink_ApplicationProps, _aws_cdk_aws_kinesisanalytics_flink_IApplication, _aws_cdk_aws_kinesisanalytics_flink_Application };
module.exports.DeprecationError = DeprecationError;
